import React, { useEffect, useRef, useState } from 'react';
import { IAnimationInOutProps } from './AnimationInOut.interface';
import AnimationInOutStyle from './AnimationInOut.style';

export function AnimationInOut({
   visible = true,
   children,
   durationIn = 300,
   durationOut = 300,
   animationOut = 'fade',
   animationIn = 'fade',
}: IAnimationInOutProps): JSX.Element {
   const ref = useRef<HTMLDivElement>();

   const [height, setHeight] = useState(0);

   if (animationOut === 'height' && !ref.current?.clientHeight) visible = false;

   useEffect(() => {
      setHeight(ref.current?.clientHeight);
   }, []);

   return (
      <AnimationInOutStyle
         visible={visible}
         durationIn={durationIn}
         durationOut={durationOut}
         animationOut={animationOut}
         animationIn={animationIn}
         style={{ height: ref.current?.clientHeight }}
      >
         <div ref={ref}>{children}</div>
      </AnimationInOutStyle>
   );
}
